<?php
/**
 * @file
 * Administration pages and code for the Google Groups module.
 */

/**
 * Lists groups entered in into the site.
 *
 * @return
 *  Page HTML.
 */
function google_groups_list_page() {
  $settings = variable_get('google_groups_settings', array());
  $header = array(t('Group name'), t('Group email'), t('Account form'), array('data' => t('Operations'), 'colspan' => '2'));
  $rows = array();

  foreach ($settings['groups'] as $delta => $group) {
    $row = array();
    $row[] = check_plain($group['name']);
    $row[] = check_plain($group['id']) . '@' . check_plain($group['domain']);

    $reg = array();
    if ($group['register']) {
      $reg[] = t('List on form: Yes');
      $reg[] = t('Default: ') . ($group['register_default'] ? t('On') : t('Off'));
      $reg[] = t('Forced: ') . ($group['register_default_forced'] ? t('Yes') : t('No'));
    } 
    else {
      $reg[] = t('List on form: No');
    }

    $row[] = theme('item_list', array('items' => $reg));
    $row[] = array('data' => l(t('edit'), 'admin/config/services/googlegroups/edit/' . $delta));
    $row[] = array('data' => l(t('delete'), 'admin/config/services/googlegroups/delete/' . $delta));

    $rows[] = $row;
  }

  if (empty($rows)) {
    $rows[] = array(array('data' => t('No Google Groups have been created.'), 'colspan' => '4', 'class' => 'message'));
  }

  $form = array();

  $form['table'] = array(
    '#theme' => 'table',
    '#header' => $header,
    '#rows' => $rows,
  );

  $form['google_groups_domain_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Group domain'),
    '#default_value' => variable_get('google_groups_domain_name', ''),
    '#required' => TRUE,
    '#size' => 40,
    '#maxlength' => 64,
  );

  $form['oauth'] = array(
    '#type' => 'fieldset',
    '#title' => t('OAuth credentials'),
    '#description' => t('The following are your OAuth <em>Web application</em> account details as gathered from the <a href="!url">Google APIs Console</a>.', array('!url' => 'https://code.google.com/apis/console/#access')),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#weight' => 2,
  );
  $form['oauth']['google_groups_oauth_client_id'] = array(
    '#type' => t('textfield'),
    '#title'=> t('Client ID'),
    '#size' => 90,
    '#default_value' => variable_get('google_groups_oauth_client_id', ''),
    '#required' => TRUE,
  );
  $form['oauth']['google_groups_oauth_email'] = array(
    '#type' => t('textfield'),
    '#title'=> t('Email address'),
    '#size' => 90,
    '#default_value' => variable_get('google_groups_oauth_email', ''),
    '#required' => TRUE,
  );
  $form['oauth']['google_groups_oauth_client_secret'] = array(
    '#type' => t('textfield'),
    '#title'=> t('Client secret:'),
    '#size' => 90,
    '#default_value' => variable_get('google_groups_oauth_client_secret', ''),
    '#required' => TRUE,
  );
  $form['oauth']['redirects'] = array(
    '#prefix' => '<div class="redirects">',
    '#markup'=> '<strong>' . t('Redirect URIs: ') . '</strong><br />' . url('admin/config/services/googlegroups', array('absolute' => TRUE)),
    '#suffix' => '</div><div class="description">' . t('Please assure this redirect is present on your Google API console') . '</div>',
  );
  $form['oauth']['google_groups_oauth_api_key'] = array(
    '#type' => t('textfield'),
    '#title'=> t('Simple API key:'),
    '#size' => 90,
    '#default_value' => variable_get('google_groups_oauth_api_key', ''),
    '#required' => TRUE,
  );

  // Only show the authorize link once we have a client ID.
  if ($client_id = variable_get('google_groups_oauth_client_id', FALSE)) {
    $path = 'https://accounts.google.com/o/oauth2/auth';
    $query = array(
      'redirect_uri' => url('admin/config/services/googlegroups', array('absolute' => TRUE)),
      'response_type' => 'code',
      'client_id' => $client_id,
      'approval_prompt' => 'force',
      'scope' => 'https://apps-apis.google.com/a/feeds/groups/',
      'access_type' => 'offline',
    );
    $url = $path . '?' . http_build_query($query, '', '&');
    
    $form['oauth']['link'] = array(
      '#prefix' => '<div class="auth">',
      '#markup'=> '<p><strong>' . t('Authorize') . '</strong> &nbsp; ' . l(t('Click me'), $url) .'</p>',
      '#suffix' => '</div><div class="description">' . t('Click the link above to authorize this website to access the Google API') . '</div>',
    );
  }

  $form['oauth']['code'] = array(
    '#prefix' => '<div class="code">',
    '#markup'=> '<strong>' . t('Current auth code') . '</strong><br />' . variable_get('google_groups_oauth_code', ''),
    '#suffix' => '</div><div class="description">' . t('Last Fetched Provision API Auth Code') . '</div>',
  );

  // Only show the tokens once we have a code.
  if ($code = variable_get('google_groups_oauth_code', FALSE)) {
    $form['oauth']['access_token'] = array(
      '#prefix' => '<div class="token">',
      '#markup'=> '<strong>' . t('Access token') . '</strong><br />' . variable_get('google_groups_oauth_access_token', ''),
      '#suffix' => '</div><div class="description">' . t('Last Fetched Provision API access Token') . '</div>',
    );
    $form['oauth']['refresh_token'] = array(
      '#prefix' => '<div class="token">',
      '#markup'=> '<strong>' . t('Refresh token') . '</strong><br />' . variable_get('google_groups_oauth_refresh_token', ''),
      '#suffix' => '</div><div class="description">' . t('Last Fetched Provision API refresh Token') . '</div>',
    );
  }

  return system_settings_form($form);
}

/**
 * Administration form.
 *
 * @return
 *  FAPI array.
 */
function google_groups_add_form() {
  $delta = (arg(4) === 'edit' && arg(5)) ? arg(5) : NULL;
  if ($delta) {
    $settings = variable_get('google_groups_settings', array());
    $group    = $settings['groups'][$delta];
  }

  $form['group_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Group Name'),
    '#default_value' => $delta ? $group['name'] : '',
    '#required' => TRUE,
    '#size' => 40,
    '#maxlength' => 100,
    '#description' => t("Your Google Group's human readable name."),
  );
  $form['group_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Group ID'),
    '#default_value' => ($delta ? $group['id'] : ''),
    '#required' => TRUE,
    '#size' => 40,
    '#maxlength' => 64,
    '#description' => t("Your Group ID is usually what comes before the @ symbol in your group email address.  For example, if your group email address is mygroup@googlegroups.com your group ID will be 'mygroup'"),
  );
  $form['register'] = array(
    '#type' => 'fieldset',
    '#title' => t('Registration Form'),
    '#description' => t('Options for subscribing via the registration form.'),
  );
  $form['register']['register'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow subscription during registration'),
    '#default_value' => ($delta ? $group['register'] : ''),
    '#description' => t('This will add a subscription checkbox to the registration form.'),
  );
  $form['register']['default'] = array(
    '#type' => 'checkbox',
    '#title' => t('Checked by default'),
    '#default_value' => ($delta ? $group['register_default'] : ''),
    '#description' => t('If checked, the subscription checkbox on the registration form will be checked by default.'),
  );
  $form['register']['forced'] = array(
    '#type' => 'checkbox',
    '#title' => t('Force default'),
    '#default_value' => ($delta ? $group['register_default_forced'] : ''),
    '#description' => t('If checked, the subscription checkbox on the registration form will be disabled. User will not be able to change it from its default setting. Useful to force user subscription.'),
  );
  $form['delta'] = array(
    '#type' => 'value',
    '#value' => $delta,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save group'),
  );

  $form['#submit'][] = 'google_groups_add_form_submit';

  return $form;
}

function google_groups_add_form_submit($form, &$form_state) {
  $settings = variable_get('google_groups_settings', array());
  $groups   = &$settings['groups'];
  $values   = &$form_state['values'];
  $delta    = check_plain($values['delta']);
  $group    = array();

  $group['name'] = check_plain($values['group_name']);
  $group['id'] = check_plain($values['group_id']);
  $group['domain'] = check_plain($values['group_domain']);
  $group['register'] = (int)$values['register'];
  $group['register_default'] = (int)$values['default'];
  $group['register_default_forced'] = (int)$values['forced'];

  if ($delta) {
    $settings['groups'][$delta] = array_merge($settings['groups'][$delta], $group);
  }
  else {
    $delta = &$settings['next_delta'];
    $settings['groups']['gg' . $delta] = $group;
    $delta++;
  }

  variable_set('google_groups_settings', $settings);
  drupal_set_message(t('Google Group saved.'), 'status');
  $form_state['redirect'] = 'admin/config/services/googlegroups';
  return;
}

/**
 * Menu callback; delete a single Google Group.
 */
function google_groups_delete_confirm(&$form_state) {
  $settings = variable_get('google_groups_settings', array());
  $delta = check_plain(arg(4));
  $form['delta'] = array(
    '#type' => 'value',
    '#value' => $delta,
  );

  $message = t('Are you sure you want to delete the Google Group @group?', array('@group' => $settings['groups'][$delta]['name']));
  $caption = '<p>'. t('This action cannot be undone.') .'</p>';

  return confirm_form($form, $message, 'admin/config/services/googlegroups', $caption, t('Delete'));
}

/**
 * Process Google Group delete confirm submissions.
 */
function google_groups_delete_confirm_submit($form, &$form_state) {
  $settings = variable_get('google_groups_settings', array());

  drupal_set_message(t('The Google Group %name has been deleted.', array('%name' => $settings['groups'][$form_state['delta']]['name'])));
  unset($settings['groups'][$form_state['values']['delta']]);
  variable_set('google_groups_settings', $settings);

  $form_state['redirect'] = 'admin/config/services/googlegroups';
  return;
}
